const margin = { top: 50, right: 50, bottom: 50, left: 50 };
const width = 800 - margin.left - margin.right;
const height = 400 - margin.top - margin.bottom;

const svg = d3
  .select('#chart')
  .append('svg')
  .attr('width', width + margin.left + margin.right)
  .attr('height', height + margin.top + margin.bottom)
  .append('g')
  .attr(
    'transform',
    `translate(${margin.left},${margin.top})`,
  );

// Load the data
d3.csv(
  'https://gist.githubusercontent.com/AsheshPinisetti/9640531cbc7790ab3f909bcdfe84d504/raw/71f1b835ae5879be36d3fb17686f3dd1b8c1a117/gistfile1.csv',
)
  .then(function (data) {
    // Create scales
    const xScale = d3
      .scaleLinear()
      .domain([0, data.length - 1])
      .range([0, width]);

    const yScale = d3
      .scaleLinear()
      .domain([
        0,
        d3.max(data, (d) => parseFloat(d.petal_length)),
      ])
      .range([height, 0]);

    // Define the area
    const area = d3
      .area()
      .x((d, i) => xScale(i))
      .y0(height)
      .y1((d) => yScale(parseFloat(d.petal_length)));

    // Append the area path
    svg
      .append('path')
      .datum(data)
      .attr('fill', 'lightblue')
      .attr('d', area);

    // Add X-axis label
    svg
      .append('text')
      .attr(
        'transform',
        `translate(${width / 2},${height + margin.top - 10})`,
      )
      .style('text-anchor', 'middle')
      .text('Index');

    // Add Y-axis label
    svg
      .append('text')
      .attr('transform', 'rotate(-90)')
      .attr('y', 0 - margin.left)
      .attr('x', 0 - height / 2)
      .attr('dy', '1em')
      .style('text-anchor', 'middle')
      .text('Petal Length');
  })
  .catch(function (error) {
    console.log('Error loading the data: ' + error);
  });
